@@ -62,7 +62,7 @@ class Worker:
         except Exception as e:
             logger.warning(f"Unable to connect to boto3 client: {e}")
 
-        if create_consumer:
+        if create_consumer and not self._sqs_opts.get("queue_url"):
             self._consumer = Worker.make_consumer(
                 loop, kafka_broker_addr, kafka_group_id, sasl_opts, consumer_opts
             )
@@ -161,9 +161,11 @@ class Worker:
         return self._exit
 
     async def start(self):
-        if self._consumer_topic:
-            self._consumer.subscribe([self._consumer_topic])
+
         if self._consumer:
+            if self._consumer_topic:
+                self._consumer.subscribe([self._consumer_topic])
+
             logger.info("Kafka consumer started")
             await self._consumer.start()
         if self._producer:
